@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Merge;
 
-our $VERSION = 'v0.39.0'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use YAML::PP::Type::MergeKey;
 
@@ -31,8 +31,7 @@ YAML::PP::Schema::Merge - Enabling YAML merge keys for mappings
 =head1 SYNOPSIS
 
     use YAML::PP;
-    my $yp = YAML::PP->new( schema => [qw/ + Merge /] );
-
+    my $yp = YAML::PP->new( schema => [qw/ JSON Merge /] );
     my $yaml = <<'EOM';
     ---
     - &CENTER { x: 1, y: 2 }
@@ -83,18 +82,11 @@ order in the sequence. Keys in mapping nodes earlier in the sequence override
 keys specified in later mapping nodes."
 
 The implementation of this in a generic way is not trivial, because we also
-have to handle duplicate keys, and YAML::PP allows you to write your own
+have to handle duplicate keys, and YAML::PP allows to write your own
 handler for processing mappings.
 
 So the inner API of that is not stable at this point.
 
-Note that if you enable this schema, a plain scalar `<<` will be seen as
-special anywhere in your document, so if you want a literal `<<`, you have
-to put it in quotes.
-
-Note that the performed merge is not a "deep merge". Only top-level keys are
-merged.
-
 =head1 METHODS
 
 =over
